<?php
/*/
Plugin Name: WP Jurist People CPT
Plugin URI: http://wpdevshed.com/wp-jurist/
Description: Creates "People" custom post type for the WP Jurist theme.
Version: 1.0
Author: WP Dev Shed
Author URI: http://wpdevshed.com/
License: GNU General Public License v2.0
License URI: http://www.gnu.org/licenses/gpl-2.0.html
/*/

/******************************************************************
 * Register the "People" custom post type
 ******************************************************************/

function jurist_cpt_people() {
	
	$labels = array(
		'name'               => _x( 'People', 'post type general name', 'wp-jurist' ),
		'singular_name'      => _x( 'People', 'post type singular name', 'wp-jurist' ),
		'add_new'            => _x( 'Add New', 'book', 'wp-jurist' ),
		'add_new_item'       => __( 'Add New People', 'wp-jurist' ),
		'edit_item'          => __( 'Edit People', 'wp-jurist' ),
		'new_item'           => __( 'New People', 'wp-jurist' ),
		'all_items'          => __( 'All People', 'wp-jurist' ),
		'view_item'          => __( 'View People', 'wp-jurist' ),
		'search_items'       => __( 'Search People', 'wp-jurist' ),
		'not_found'          => __( 'No People found', 'wp-jurist' ),
		'not_found_in_trash' => __( 'No People found in the Trash', 'wp-jurist' ), 
		'parent_item_colon'  => '',
		'menu_name'          => 'People'
	);
	
	$args = array(
		'labels'        => $labels,
		'description'   => __('Holds our people and people specific data', 'wp-jurist'),
		'public'        => true,
		'menu_position' => 5,
		'supports'      => array( 'title', 'editor', 'thumbnail', 'excerpt', 'comments' ),
		'has_archive'   => false,
		
	);
	register_post_type( 'people', $args );	
}
add_action( 'init', 'jurist_cpt_people' );



/* Flush your rewrite rules */
function jurist_flush_rewrite_rules() {
	global $pagenow;
	if ( 'themes.php' == $pagenow && isset( $_GET['activated'] ) )
		flush_rewrite_rules();
}
/* Flush rewrite rules for custom post types. */
add_action( 'load-themes.php', 'jurist_flush_rewrite_rules' );



/* Custom Taxonomies for Menu Item */
function jurist_taxonomies_people() {
	$labels = array(
		'name'              => _x( 'People Categories', 'taxonomy general name', 'wp-jurist' ),
		'singular_name'     => _x( 'People Category', 'taxonomy singular name', 'wp-jurist' ),
		'search_items'      => __( 'Search People Categories', 'wp-jurist' ),
		'all_items'         => __( 'All People Categories', 'wp-jurist' ),
		'parent_item'       => __( 'Parent People Category', 'wp-jurist' ),
		'parent_item_colon' => __( 'Parent People Category:', 'wp-jurist' ),
		'edit_item'         => __( 'Edit People Category', 'wp-jurist' ), 
		'update_item'       => __( 'Update People Category', 'wp-jurist' ),
		'add_new_item'      => __( 'Add New People Category', 'wp-jurist' ),
		'new_item_name'     => __( 'New People Category', 'wp-jurist' ),
		'menu_name'         => __( 'People Categories', 'wp-jurist' ),
	);
	$args = array(
		'labels' => $labels,
		'hierarchical' => true,
	);
	register_taxonomy( 'people_category', 'people', $args );
}
add_action( 'init', 'jurist_taxonomies_people', 0 );


/* Job Title Meta Box */

function jurist_people_job_title() {
    add_meta_box( 
        'people_job_title_box',
        __( 'Job Title', 'wp-jurist' ),
        'jurist_people_job_title_content',
        'people',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'jurist_people_job_title' );

function jurist_people_job_title_content( $people_job_title ) {

	$jurist_title = get_post_meta( $people_job_title->ID, 'job_title', true );
	echo '<input type="hidden" name="jurist_noncename" id="jurist_noncename" value="' . wp_create_nonce( 'wpdevshed-nonce' ) . '" />';
	echo '<label for="people_job_title">' . __('Enter the Job Title', 'wp-jurist') . '</label>';
	echo '<input id=people_job_title" name="people_job_title" style="width: 100%" type="text" value="'.$jurist_title.'" />';
}

function jurist_job_title_save( $people_job_title ) {

	// If it is our form has not been submitted, so we dont want to do anything
    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }
	
	// verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (isset($_POST['jurist_noncename'])){
        if ( !wp_verify_nonce( $_POST['jurist_noncename'], 'wpdevshed-nonce' ) )
            return;
    }else{return;}
	
	// Check permissions
    if ( 'people' == $people_job_title->post_type ) { if ( !current_user_can( 'edit_page', $people_job_title )) { return $people_job_title; }}
    elseif ( !current_user_can( 'edit_post', $people_job_title )) { return $people_job_title;}


	update_post_meta( $people_job_title, 'job_title', $_POST['people_job_title'] );
}
add_action( 'save_post', 'jurist_job_title_save' );



/* Phone Number Meta Box */

function jurist_people_phone_number() {
    add_meta_box( 
        'people_phone_number_box',
        __( 'Phone Number', 'wp-jurist' ),
        'jurist_people_phone_number_content',
        'people',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'jurist_people_phone_number' );

function jurist_people_phone_number_content( $people_phone_number) {

	$jurist_phone = get_post_meta( $people_phone_number->ID, 'phone_number', true );
	echo '<input type="hidden" name="jurist_noncename2" id="jurist_noncename2" value="' . wp_create_nonce( 'wpdevshed-nonce2' ) . '" />';
	echo '<label for="people_phone_number">' . __('Enter the Phone Number', 'wp-jurist') . '</label>';
	echo '<input id="people_phone_number" name="people_phone_number" style="width: 100%" type="text" value="'.$jurist_phone.'" />';
}

function jurist_phone_number_save( $people_phone_number ) {

	// If it is our form has not been submitted, so we dont want to do anything
    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }
	
	// verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (isset($_POST['jurist_noncename2'])){
        if ( !wp_verify_nonce( $_POST['jurist_noncename2'], 'wpdevshed-nonce2' ) )
            return;
    }else{return;}
	
	// Check permissions
    if ( 'people' == $people_phone_number->post_type ) { if ( !current_user_can( 'edit_page', $people_phone_number )) { return $people_phone_number; }}
    elseif ( !current_user_can( 'edit_post', $people_phone_number )) { return $people_phone_number;}

	
	update_post_meta( $people_phone_number, 'phone_number', $_POST['people_phone_number'] );
}
add_action( 'save_post', 'jurist_phone_number_save' );


/* LinkedIn Meta Box */

function jurist_people_linkedin() {
    add_meta_box( 
        'people_linkedin_box',
        __( 'LinkedIn', 'wp-jurist' ),
        'jurist_people_linkedin_content',
        'people',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'jurist_people_linkedin' );

function jurist_people_linkedin_content( $people_linkedin ) {

	$jurist_linkedin = get_post_meta( $people_linkedin->ID, 'linkedin', true );
	echo '<input type="hidden" name="jurist_noncename3" id="jurist_noncename3" value="' . wp_create_nonce( 'wpdevshed-nonce3' ) . '" />';
	echo '<label for="people_linkedin">' . __('Enter the LinkedIn Profile URL', 'wp-jurist') . '</label>';
	echo '<input id="people_linkedin" name="people_linkedin" style="width: 100%" type="text" value="'.$jurist_linkedin.'" />';
}

function jurist_linkedin_save( $people_linkedin ) {

	// If it is our form has not been submitted, so we dont want to do anything
    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }
	
	// verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (isset($_POST['jurist_noncename3'])){
        if ( !wp_verify_nonce( $_POST['jurist_noncename3'], 'wpdevshed-nonce3' ) )
            return;
    }else{return;}
	
	// Check permissions
    if ( 'people' == $people_linkedin->post_type ) { if ( !current_user_can( 'edit_page', $people_linkedin )) { return $people_linkedin; }}
    elseif ( !current_user_can( 'edit_post', $people_linkedin )) { return $people_linkedin;}

	
	update_post_meta( $people_linkedin, 'linkedin', $_POST['people_linkedin'] );
}
add_action( 'save_post', 'jurist_linkedin_save' );


/* Twitter Meta Box */

function jurist_people_twitter() {
    add_meta_box( 
        'people_twitter_box',
        __( 'Twitter', 'wp-jurist' ),
        'jurist_people_twitter_content',
        'people',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'jurist_people_twitter' );

function jurist_people_twitter_content( $people_twitter ) {

	$jurist_twitter = get_post_meta( $people_twitter->ID, 'twitter', true );
	echo '<input type="hidden" name="jurist_noncename4" id="jurist_noncename4" value="' . wp_create_nonce( 'wpdevshed-nonce4' ) . '" />';
	echo '<label for="people_twitter">' . __('Enter the Twitter Profile URL', 'wp-jurist') . '</label>';
	echo '<input id="people_twitter" name="people_twitter" style="width: 100%" type="text" value="'.$jurist_twitter.'" />';
}

function jurist_twitter_save( $people_twitter ) {

	// If it is our form has not been submitted, so we dont want to do anything
    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }
	
	// verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (isset($_POST['jurist_noncename4'])){
        if ( !wp_verify_nonce( $_POST['jurist_noncename4'], 'wpdevshed-nonce4' ) )
            return;
    }else{return;}
	
	// Check permissions
    if ( 'people' == $people_twitter->post_type ) { if ( !current_user_can( 'edit_page', $people_twitter )) { return $people_twitter; }}
    elseif ( !current_user_can( 'edit_post', $people_twitter )) { return $people_twitter;}

	
	update_post_meta( $people_twitter, 'twitter', $_POST['people_twitter'] );
}
add_action( 'save_post', 'jurist_twitter_save' );


/* Facebook Meta Box */

function jurist_people_facebook() {
    add_meta_box( 
        'people_facebook_box',
        __( 'Facebook', 'wp-jurist' ),
        'jurist_people_facebook_content',
        'people',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'jurist_people_facebook' );

function jurist_people_facebook_content( $people_facebook ) {

	$jurist_facebook = get_post_meta( $people_facebook->ID, 'facebook', true );
	echo '<input type="hidden" name="jurist_noncename5" id="jurist_noncename5" value="' . wp_create_nonce( 'wpdevshed-nonce5' ) . '" />';
	echo '<label for="people_facebook">' . __('Enter the Facebook Profile URL', 'wp-jurist') . '</label>';
	echo '<input id="people_facebook" name="people_facebook" style="width: 100%" type="text" value="'.$jurist_facebook.'" />';
}

function jurist_facebook_save( $people_facebook ) {

	// If it is our form has not been submitted, so we dont want to do anything
    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }
	
	// verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (isset($_POST['jurist_noncename5'])){
        if ( !wp_verify_nonce( $_POST['jurist_noncename5'], 'wpdevshed-nonce5' ) )
            return;
    }else{return;}
	
	// Check permissions
    if ( 'people' == $people_facebook->post_type ) { if ( !current_user_can( 'edit_page', $people_facebook )) { return $people_facebook; }}
    elseif ( !current_user_can( 'edit_post', $people_facebook )) { return $people_facebook;}

	
	update_post_meta( $people_facebook, 'facebook', $_POST['people_facebook'] );
}
add_action( 'save_post', 'jurist_facebook_save' );


/* Google+ Meta Box */

function jurist_people_googlep() {
    add_meta_box( 
        'people_googlep_box',
        __( 'Google+', 'wp-jurist' ),
        'jurist_people_googlep_content',
        'people',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'jurist_people_googlep' );

function jurist_people_googlep_content( $people_googlep ) {

	$jurist_googlep = get_post_meta( $people_googlep->ID, 'googlep', true );
	echo '<input type="hidden" name="jurist_noncename6" id="jurist_noncename6" value="' . wp_create_nonce( 'wpdevshed-nonce6' ) . '" />';
	echo '<label for="people_googlep">' . __('Enter the Google+ Profile URL', 'wp-jurist') . '</label>';
	echo '<input id="people_googlep" name="people_googlep" style="width: 100%" type="text" value="'.$jurist_googlep.'" />';
}

function jurist_googlep_save( $people_googlep ) {

	// If it is our form has not been submitted, so we dont want to do anything
    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }
	
	// verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (isset($_POST['jurist_noncename6'])){
        if ( !wp_verify_nonce( $_POST['jurist_noncename6'], 'wpdevshed-nonce6' ) )
            return;
    }else{return;}
	
	// Check permissions
    if ( 'people' == $people_googlep->post_type ) { if ( !current_user_can( 'edit_page', $people_googlep )) { return $people_googlep; }}
    elseif ( !current_user_can( 'edit_post', $people_googlep )) { return $people_googlep;}

	
	update_post_meta( $people_googlep, 'googlep', $_POST['people_googlep'] );
}
add_action( 'save_post', 'jurist_googlep_save' );


/* Email Meta Box */

function jurist_people_email() {
    add_meta_box( 
        'people_email_box',
        __( 'Email', 'wp-jurist' ),
        'jurist_people_email_content',
        'people',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'jurist_people_email' );

function jurist_people_email_content( $people_email ) {

	$jurist_email = get_post_meta( $people_email->ID, 'email', true );
	echo '<input type="hidden" name="jurist_noncename7" id="jurist_noncename7" value="' . wp_create_nonce( 'wpdevshed-nonce7' ) . '" />';
	echo '<label for="people_email">' . __('Enter the Email Address', 'wp-jurist') . '</label>';
	echo '<input id="people_email" name="people_email" style="width: 100%" type="text" value="'.$jurist_email.'" />';
}

function jurist_email_save( $people_email ) {

	// If it is our form has not been submitted, so we dont want to do anything
    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }
	
	// verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (isset($_POST['jurist_noncename7'])){
        if ( !wp_verify_nonce( $_POST['jurist_noncename7'], 'wpdevshed-nonce7' ) )
            return;
    }else{return;}
	
	// Check permissions
    if ( 'people' == $people_email->post_type ) { if ( !current_user_can( 'edit_page', $people_email )) { return $people_email; }}
    elseif ( !current_user_can( 'edit_post', $people_email )) { return $people_email;}

	
	update_post_meta( $people_email, 'email', $_POST['people_email'] );
}
add_action( 'save_post', 'jurist_email_save' );


/* Avvo Meta Box */

function jurist_people_avvo() {
    add_meta_box( 
        'people_avvo_box',
        __( 'Avvo', 'wp-jurist' ),
        'jurist_people_avvo_content',
        'people',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'jurist_people_avvo' );

function jurist_people_avvo_content( $people_avvo ) {

	$jurist_avvo = get_post_meta( $people_avvo->ID, 'avvo', true );
	echo '<input type="hidden" name="jurist_noncename8" id="jurist_noncename8" value="' . wp_create_nonce( 'wpdevshed-nonce8' ) . '" />';
	echo '<label for="people_avvo">' . __('Enter the Avvo Profile URL', 'wp-jurist') . '</label>';
	echo '<input id="people_avvo" name="people_avvo" style="width: 100%" type="text" value="'.$jurist_avvo.'" />';
}

function jurist_avvo_save( $people_avvo ) {

	// If it is our form has not been submitted, so we dont want to do anything
    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
        return;
    }
	
	// verify this came from the our screen and with proper authorization,
    // because save_post can be triggered at other times
    if (isset($_POST['jurist_noncename8'])){
        if ( !wp_verify_nonce( $_POST['jurist_noncename8'], 'wpdevshed-nonce8' ) )
            return;
    }else{return;}
	
	// Check permissions
    if ( 'people' == $people_avvo->post_type ) { if ( !current_user_can( 'edit_page', $people_avvo )) { return $people_avvo; }}
    elseif ( !current_user_can( 'edit_post', $people_avvo )) { return $people_avvo;}

	
	update_post_meta( $people_avvo, 'avvo', $_POST['people_avvo'] );
}
add_action( 'save_post', 'jurist_avvo_save' );


?>